@@ -43,7 +43,7 @@ import sys
 from typing import IO, TYPE_CHECKING, Any, List, Optional, Tuple
 
 from cobib import __version__
-from cobib.config import config
+from cobib.config import Event, config
 from cobib.database import Database
 
 from .base_command import ArgumentParser, Command
@@ -119,10 +119,12 @@ class SearchCommand(Command):
             largs = parser.parse_intermixed_args(args)
         except argparse.ArgumentError as exc:
             LOGGER.error(exc.message)
-            print(exc.message, file=sys.stderr)
             return None
 
-        labels = ListCommand().execute(largs.filter, out=open(os.devnull, "w"))
+        Event.PreSearchCommand.fire(largs)
+
+        with open(os.devnull, "w", encoding="utf-8") as devnull:
+            labels = ListCommand().execute(largs.filter, out=devnull)
         if labels is None:
             return None  # pragma: no cover
         LOGGER.debug("Available entries to search: %s", labels)
@@ -159,6 +161,9 @@ class SearchCommand(Command):
                     output.append(f"[{idx+1}]\t".expandtabs(8) + line)
 
         print("\n".join(output), file=out)
+
+        Event.PostSearchCommand.fire(hits, labels)
+
         return (hits, labels)
 
     @staticmethod
@@ -196,9 +201,7 @@ class SearchCommand(Command):
             tui.STATE.top_line = 0
             tui.STATE.current_line = 0
             # update top statusbar
-            tui.STATE.topstatus = "coBib v{} - {} hit{}".format(
-                __version__, hits, "s" if hits > 1 else ""
-            )
+            tui.STATE.topstatus = f"coBib v{__version__} - {hits} hit{'s' if hits > 1 else ''}"
             tui.statusbar(tui.topbar, tui.STATE.topstatus)
             tui.STATE.inactive_commands = ["Add", "Filter", "Sort"]
         elif command[1:]:
