@@ -62,6 +62,7 @@ class Config(Dict[str, Any]):
 
     DEFAULTS: Dict[str, Any] = {
         "logging": {
+            "cache": "~/.cache/cobib/cache",
             "logfile": "~/.cache/cobib/cobib.log",
             "version": "~/.cache/cobib/version",
         },
@@ -72,6 +73,7 @@ class Config(Dict[str, Any]):
             },
             "open": {
                 "command": "xdg-open" if sys.platform.lower() == "linux" else "open",
+                "fields": ["file", "url"],
             },
             "search": {
                 "grep": "grep",
@@ -100,6 +102,9 @@ class Config(Dict[str, Any]):
             "bibtex": {
                 "ignore_non_standard_types": False,
             },
+            "yaml": {
+                "use_c_lib_yaml": False,
+            },
         },
         "tui": {
             "default_list_args": ["-l"],
@@ -134,6 +139,7 @@ class Config(Dict[str, Any]):
                 "delete": "d",
                 "edit": "e",
                 "filter": "f",
+                "import": "i",
                 "modify": "m",
                 "open": "o",
                 "quit": "q",
@@ -407,6 +413,9 @@ class Config(Dict[str, Any]):
 
         # LOGGING section
         LOGGER.debug("Validating the LOGGING configuration section.")
+        self._assert(
+            isinstance(self.logging.cache, str), "config.logging.cache should be a string."
+        )
         self._assert(
             isinstance(self.logging.logfile, str), "config.logging.logfile should be a string."
         )
@@ -433,6 +442,10 @@ class Config(Dict[str, Any]):
             isinstance(self.commands.open.command, str),
             "config.commands.open.command should be a string.",
         )
+        self._assert(
+            isinstance(self.commands.open.fields, list),
+            "config.commands.open.fields should be a list.",
+        )
         # COMMANDS.SEARCH section
         LOGGER.debug("Validating the COMMANDS.SEARCH configuration section.")
         self._assert(
@@ -510,6 +523,15 @@ class Config(Dict[str, Any]):
             isinstance(self.parsers.bibtex.ignore_non_standard_types, bool),
             "config.parsers.bibtex.ignore_non_standard_types should be a boolean.",
         )
+        self._assert(
+            isinstance(self.parsers.yaml.use_c_lib_yaml, bool),
+            "config.parsers.yaml.use_c_lib_yaml should be a boolean.",
+        )
+        if self.parsers.yaml.use_c_lib_yaml is False:
+            LOGGER.warning(
+                "The config.parsers.yaml.use_c_lib_yaml setting (introduced in version 3.4.0) will "
+                "change its default value to `True` in version 4.0.0!"
+            )
 
         # TUI section
         self._assert(
