@@ -19,7 +19,7 @@ from typing import Dict
 
 import bibtexparser
 
-from cobib.config import config
+from cobib.config import Event, config
 from cobib.database import Entry
 
 from .base_parser import Parser
@@ -35,13 +35,16 @@ class BibtexParser(Parser):
     def parse(self, string: str) -> Dict[str, Entry]:
         # pdoc will inherit the docstring from the base class
         # noqa: D102
+
+        string = Event.PreBibtexParse.fire(string) or string
+
         bparser = bibtexparser.bparser.BibTexParser()
         bparser.ignore_nonstandard_types = config.parsers.bibtex.ignore_non_standard_types
         bparser.common_strings = True
         bparser.interpolate_strings = False
         try:
             LOGGER.debug("Loading BibTex data from file: %s.", string)
-            with open(string, "r") as file:
+            with open(string, "r", encoding="utf-8") as file:
                 database = bibtexparser.load(file, parser=bparser)
         except (OSError, FileNotFoundError):
             LOGGER.debug("Loading BibTex string: %s.", string)
@@ -54,13 +57,20 @@ class BibtexParser(Parser):
                 entry["month"] = entry["month"].expr[0].name
             label = entry.pop("ID")
             bib[label] = Entry(label, entry)
+
+        Event.PostBibtexParse.fire(bib)
+
         return bib
 
     def dump(self, entry: Entry) -> str:
         # pdoc will inherit the docstring from the base class
         # noqa: D102
+
+        Event.PreBibtexDump.fire(entry)
+
         database = bibtexparser.bibdatabase.BibDatabase()
         stringified_entry = entry.stringify()
+        stringified_entry["ID"] = stringified_entry.pop("label")
         if "month" in stringified_entry.keys():
             # convert month to bibtexexpression
             stringified_entry["month"] = bibtexparser.bibtexexpression.BibDataStringExpression(
@@ -71,4 +81,7 @@ class BibtexParser(Parser):
         writer = bibtexparser.bwriter.BibTexWriter()
         writer.common_strings = True
         string: str = writer.write(database)
+
+        string = Event.PostBibtexDump.fire(string) or string
+
         return string
