@@ -15,11 +15,11 @@ import io
 import logging
 from collections import OrderedDict
 from pathlib import Path
-from typing import IO, Dict, Optional, Union, cast
+from typing import IO, Dict, Optional, Union
 
 from ruamel import yaml
 
-from cobib.config import Event
+from cobib.config import Event, config
 from cobib.database import Entry
 
 from .base_parser import Parser
@@ -32,24 +32,18 @@ class YAMLParser(Parser):
 
     name = "yaml"
 
-    class YamlDumper(yaml.YAML):  # type: ignore
-        """Wrapper class for YAML dumping."""
+    _yaml: Optional[yaml.YAML] = None  # type: ignore[name-defined]
 
-        # pylint: disable=arguments-differ,inconsistent-return-statements
-        def dump(self, data, stream=None, **kw) -> Optional[str]:  # type: ignore
-            """A wrapper to dump as a string.
-
-            Adapted from
-            [here](https://yaml.readthedocs.io/en/latest/example.html#output-of-dump-as-a-string).
-            """
-            inefficient = False
-            if stream is None:  # pragma: no branch
-                inefficient = True
-                stream = yaml.compat.StringIO()
-            yaml.YAML.dump(self, data, stream, **kw)  # type: ignore
-            if inefficient:
-                return cast(str, stream.getvalue())
-            return None  # pragma: no cover
+    def __init__(self) -> None:  # pylint: disable=C0116
+        # noqa: D107
+        if YAMLParser._yaml is None:
+            # we need to lazily construct this in order to be able to respect the config setting
+            YAMLParser._yaml = yaml.YAML(  # type: ignore[attr-defined]
+                typ="safe", pure=not config.parsers.yaml.use_c_lib_yaml
+            )
+            YAMLParser._yaml.explicit_start = True
+            YAMLParser._yaml.explicit_end = True
+            YAMLParser._yaml.default_flow_style = False
 
     def parse(self, string: Union[str, Path]) -> Dict[str, Entry]:
         # pdoc will inherit the docstring from the base class
@@ -60,14 +54,13 @@ class YAMLParser(Parser):
         bib = OrderedDict()
         LOGGER.debug("Loading YAML data from file: %s.", string)
         try:
-            stream: IO = io.StringIO(Path(string))  # type: ignore
+            stream: IO = io.StringIO(Path(string))  # type: ignore[arg-type,type-arg]
         except TypeError:
             try:
                 stream = open(string, "r", encoding="utf-8")  # pylint: disable=consider-using-with
             except FileNotFoundError as exc:
                 raise exc
-        yml = yaml.YAML(typ="safe", pure=True)  # type: ignore
-        for entry in yml.load_all(stream):
+        for entry in self._yaml.load_all(stream):  # type: ignore[union-attr]
             for label, data in entry.items():
                 bib[label] = Entry(label, data)
         stream.close()
@@ -82,11 +75,12 @@ class YAMLParser(Parser):
 
         Event.PreYAMLDump.fire(entry)
 
-        yml = self.YamlDumper()
-        yml.explicit_start = True
-        yml.explicit_end = True
         LOGGER.debug("Converting entry %s to YAML format.", entry.label)
-        string = yml.dump({entry.label: dict(sorted(entry.data.items()))})
+        stream = io.StringIO()
+        self._yaml.dump(  # type: ignore[union-attr]
+            {entry.label: dict(sorted(entry.data.items()))}, stream=stream
+        )
+        string = stream.getvalue()
 
         string = Event.PostYAMLDump.fire(string) or string
 
