@@ -57,6 +57,7 @@ from typing import IO, Any, Callable, Dict, List, Optional, Set, Tuple, Union, c
 
 from cobib import commands
 from cobib.config import config
+from cobib.utils.file_downloader import FileDownloader
 
 from .buffer import InputBuffer, TextBuffer
 from .frame import Frame
@@ -107,6 +108,7 @@ class TUI:
         "Export": commands.export.ExportCommand.tui,
         "Filter": commands.list.ListCommand.tui_filter,
         "Help": lambda self: self.help(),
+        "Import": commands.import_.ImportCommand.tui,
         "Modify": commands.modify.ModifyCommand.tui,
         "Open": commands.open.OpenCommand.tui,
         "Prompt": lambda self: self.execute_command(None),
@@ -130,6 +132,7 @@ class TUI:
         "Export": "Allows exporting the database to .bib or .zip files.",
         "Filter": "Allows filtering the list via `++/--` keywords.",
         "Help": "Displays this help.",
+        "Import": "Imports entries from another bibliography manager.",
         "Modify": "Allows basic modification of multiple entries at once.",
         "Open": "Opens the associated file of an entry.",
         "Prompt": "Executes arbitrary coBib CLI commands in the prompt.",
@@ -176,6 +179,10 @@ class TUI:
         LOGGER.info("Initializing TUI.")
         self.stdscr = stdscr
 
+        # redirect stdout and stderr
+        self.stdout = sys.stdout = TextBuffer()  # type: ignore
+        self.stderr = sys.stderr = TextBuffer()  # type: ignore
+
         # register resize handler
         signal.signal(signal.SIGWINCH, self.resize_handler)
 
@@ -222,6 +229,9 @@ class TUI:
         # The prompt is a pad to allow command/error prompts to exceed the terminal width.
         self.prompt = curses.newpad(1, self.width)
 
+        # set prompt line as output source of the global file downloader
+        FileDownloader().set_logger(self.prompt_print)
+
         # Initialize main viewport
         LOGGER.debug("Initializing viewport with Frame")
         # NOTE: -3 accounts for the top and bottom statusline as well as the command prompt
@@ -264,6 +274,7 @@ class TUI:
         # actually resize the terminal
         curses.resize_term(self.height, self.width)
         # clear and refresh for a blank canvas
+        self.stdscr.keypad(True)
         self.stdscr.clear()
         self.stdscr.refresh()
         # update top statusbar
@@ -323,7 +334,7 @@ class TUI:
         color_cfg = config.tui.colors
         colors: Dict[str, Dict[str, str]] = {col: {} for col in TUI.COLOR_NAMES}
         for attr, col in color_cfg.items():
-            if attr in TUI.COLOR_VALUES.keys():
+            if attr in TUI.COLOR_VALUES:
                 if not curses.can_change_color():
                     # cannot change curses default colors
                     LOGGER.warning("Curses cannot change the default colors. Skipping color setup.")
@@ -387,10 +398,11 @@ class TUI:
         for cmd in TUI.HELP_DICT:
             # get associated key for this command
             key = config.tui.key_bindings[cmd.lower()]
-            infoline += " {}:{}".format(key, cmd)
+            infoline += f" {key}:{cmd}"
         return infoline.strip()
 
     def help(self) -> None:
+        # pylint: disable=consider-using-f-string
         """The Help Command.
 
         Opens a popup with more detailed information on the configured key bindings and short
@@ -417,17 +429,20 @@ class TUI:
         # open help popup
         help_text.popup(self, background=TUI.COLOR_NAMES.index("popup_help"))
 
-    def loop(self) -> None:
+    def loop(self, debug: bool = False) -> None:
         """The key-handling event loop.
 
         This method takes care of reading the user's key strokes and triggering associated commands.
+
+        Args:
+            debug: if True, the key-event loop is not automatically started.
         """
         key = 0
         # key is the last character pressed
         while True:
             # handle possible keys
             try:
-                if key in TUI.KEYDICT.keys():
+                if key in TUI.KEYDICT:
                     cmd = TUI.KEYDICT[key]
                     if cmd not in STATE.inactive_commands:
                         if isinstance(cmd, tuple):
@@ -439,6 +454,8 @@ class TUI:
             except StopIteration:
                 LOGGER.debug("Stopping key event loop.")
                 # raised by quit command
+                sys.stdout = sys.__stdout__
+                sys.stderr = sys.__stderr__
                 break
 
             # highlight current line
@@ -463,6 +480,19 @@ class TUI:
                     # otherwise, we remove the stored attributes in order to not reset them later
                     current_attributes[-1] = None
 
+            for stream, name in zip((self.stderr, self.stdout), ("stderr", "stdout")):
+                stream.flush()
+                if stream.lines:
+                    stream.split()
+                    LOGGER.info("sys.%s contains:\n%s", name, "\n".join(stream.lines))
+                    # wrap before checking the height:
+                    stream.wrap(self.width)
+                    if stream.height > 1 and not debug:
+                        stream.popup(self, background=TUI.COLOR_NAMES.index(f"popup_{name}"))
+                    else:
+                        self.prompt_print(stream.lines)
+                    stream.clear()
+
             # Refresh the screen
             self.viewport.refresh()
 
@@ -634,7 +664,11 @@ class TUI:
         if not skip_prompt:
             command = self.prompt_handler(cast(str, command))
             # split command into separate arguments for cobib
-            command = shlex.split(command)
+            try:
+                command = shlex.split(command)
+            except ValueError:
+                LOGGER.error("Invalid command: %s", command)
+                return ([""], None)
 
         command = cast(List[str], command)
 
@@ -642,14 +676,8 @@ class TUI:
         result = None
         if command and command[0]:
             LOGGER.debug("Processing the command: %s", " ".join(command))
-            # temporarily disable prints to stdout, stderr and stdin
-            original_stdin = sys.stdin
-            original_stdout = sys.stdout
-            original_stderr = sys.stderr
-            stdout = sys.stdout = TextBuffer()  # type: ignore
-            stderr = sys.stderr = TextBuffer()  # type: ignore
-            sys.stdin = InputBuffer(buffer=stdout, tui=self)  # type: ignore
             # run command
+            sys.stdin = InputBuffer(buffer=self.stdout, tui=self)  # type: ignore
             subcmd = getattr(commands, command[0].title() + "Command")()
             try:
                 if pass_selection:
@@ -658,32 +686,6 @@ class TUI:
                 result = subcmd.execute(command[1:], out=out)
             except SystemExit:  # pragma: no cover
                 pass  # pragma: no cover
-            # if error occurred print info to prompt
-            if stderr.lines:
-                LOGGER.warning('The command "%s" resulted in an error.', " ".join(command))
-                stderr.split()
-                LOGGER.info("sys.stderr contains:\n%s", "\n".join(stderr.lines))
-                # wrap before checking the height:
-                stderr.wrap(self.width)
-                if stderr.height > 1:
-                    stderr.popup(self, background=TUI.COLOR_NAMES.index("popup_stderr"))
-                else:
-                    self.prompt_print(stderr.lines)
-                # command exited with an error
-                self.viewport.update_list()
-            elif stdout.lines:
-                LOGGER.info('A message to stdout from "%s" was intercepted.', " ".join(command))
-                stdout.split()
-                LOGGER.info("sys.stdout contains:\n%s", "\n".join(stdout.lines))
-                # wrap before checking the height:
-                stdout.wrap(self.width)
-                if stdout.height > 1:
-                    stdout.popup(self, background=TUI.COLOR_NAMES.index("popup_stdout"))
-                else:
-                    self.prompt_print(stdout.lines)
-            # restore stdout, stderr and stdin
-            sys.stdout = original_stdout
-            sys.stderr = original_stderr
-            sys.stdin = original_stdin
+            sys.stdin = sys.__stdin__
         # return command to enable additional handling by function caller
         return (command, result)
