@@ -3,16 +3,20 @@
 
 from __future__ import annotations
 
+import contextlib
 import logging
 import os
 import subprocess
+from argparse import Namespace
+from io import StringIO
+from pathlib import Path
 from shutil import rmtree
 from typing import TYPE_CHECKING, Any, Type
 
 import pytest
 
 from cobib.commands import AddCommand, RedoCommand, UndoCommand
-from cobib.config import config
+from cobib.config import Event, config
 from cobib.database import Database
 
 from .. import get_resource
@@ -125,8 +129,8 @@ class TestRedoCommand(CommandTest, TUITest):
 
         RedoCommand().execute([])
         self._assert()
-        assert "Storing redone commit" in caplog.record_tuples[3][2]
-        assert "Skipping" in caplog.record_tuples[5][2]
+        assert "Storing redone commit" in caplog.record_tuples[4][2]
+        assert "Skipping" in caplog.record_tuples[6][2]
 
     @pytest.mark.parametrize(
         ["setup"],
@@ -194,7 +198,9 @@ class TestRedoCommand(CommandTest, TUITest):
 
         # initialize git-tracking
         os.makedirs(self.COBIB_TEST_DIR, exist_ok=True)
-        open(config.database.file, "w").close()  # pylint: disable=consider-using-with
+        open(  # pylint: disable=consider-using-with
+            config.database.file, "w", encoding="utf-8"
+        ).close()
         os.system("git init " + str(self.COBIB_TEST_DIR))
 
         try:
@@ -234,3 +240,42 @@ class TestRedoCommand(CommandTest, TUITest):
         AddCommand().execute(["-b", EXAMPLE_MULTI_FILE_ENTRY_BIB])
         UndoCommand().execute([])
         self.run_tui("r", assertion, {})
+
+    @pytest.mark.parametrize("setup", [{"git": True}], indirect=["setup"])
+    def test_event_pre_redo_command(self, setup: Any) -> None:
+        """Tests the PreRedoCommand event."""
+
+        @Event.PreRedoCommand.subscribe
+        def hook(largs: Namespace) -> None:
+            print("Hello world!")
+
+        assert Event.PreRedoCommand.validate()
+
+        with contextlib.redirect_stdout(StringIO()) as out:
+            with pytest.raises(SystemExit):
+                RedoCommand().execute([])
+
+            assert out.getvalue() == "Hello world!\n"
+
+    @pytest.mark.parametrize("setup", [{"git": True}], indirect=["setup"])
+    def test_event_post_redo_command(self, setup: Any) -> None:
+        """Tests the PostRedoCommand event."""
+
+        @Event.PostRedoCommand.subscribe
+        def hook(root: Path, sha: str) -> None:
+            print(root)
+
+        assert Event.PostRedoCommand.validate()
+
+        with contextlib.redirect_stdout(StringIO()) as out:
+            AddCommand().execute(["-b", EXAMPLE_MULTI_FILE_ENTRY_BIB])
+            UndoCommand().execute([])
+
+            if Database().get("example_multi_file_entry", None) is not None:
+                pytest.skip("UndoCommand failed. No point in attempting Redo.")
+
+            RedoCommand().execute([])
+
+            self._assert()
+
+            assert out.getvalue() == f"{self.COBIB_TEST_DIR}\n"
