@@ -18,9 +18,9 @@ EXAMPLE_LITERATURE = get_resource("example_literature.yaml")
 def test_config_init() -> None:
     """Test Config initialization."""
     # empty init
-    assert Config() == {}
+    assert Config() == {}  # pylint: disable=C1803
     # init from empty dictionary
-    assert Config({}) == {}
+    assert Config({}) == {}  # pylint: disable=C1803
     # init from dictionary
     assert Config({"dummy": "test"}) == {"dummy": "test"}
     # init from non-dictionary
@@ -177,6 +177,7 @@ def test_config_validation(setup: Any) -> None:
         [["commands", "edit"], "default_entry_type"],
         [["commands", "edit"], "editor"],
         [["commands", "open"], "command"],
+        [["commands", "open"], "fields"],
         [["commands", "search"], "grep"],
         [["commands", "search"], "grep_args"],
         [["commands", "search"], "ignore_case"],
@@ -189,6 +190,7 @@ def test_config_validation(setup: Any) -> None:
         [["database", "stringify", "list_separator"], "tags"],
         [["database", "stringify", "list_separator"], "url"],
         [["parsers", "bibtex"], "ignore_non_standard_types"],
+        [["parsers", "yaml"], "use_c_lib_yaml"],
         [["tui"], "default_list_args"],
         [["tui"], "prompt_before_quit"],
         [["tui"], "reverse_order"],
@@ -218,6 +220,7 @@ def test_config_validation(setup: Any) -> None:
         [["tui", "key_bindings"], "delete"],
         [["tui", "key_bindings"], "edit"],
         [["tui", "key_bindings"], "filter"],
+        [["tui", "key_bindings"], "import"],
         [["tui", "key_bindings"], "modify"],
         [["tui", "key_bindings"], "open"],
         [["tui", "key_bindings"], "quit"],
